@@ -6,8 +6,8 @@
 
 ;; Maintainer: Étienne Deparis <etienne@depar.is>
 ;; Author: film42
-;; Package-Version: 20250625.2011
-;; Package-Revision: ad30f50e06c1
+;; Package-Version: 20260224.1455
+;; Package-Revision: b1a4d87ba1cf
 ;; Package-Requires: ((emacs "24.3"))
 ;; URL: https://github.com/dracula/emacs
 
@@ -153,6 +153,11 @@ The theme has to be reloaded after changing anything in this group."
   :type 'boolean
   :group 'dracula)
 
+(defcustom dracula-bolder-keywords t
+  "Use bold weight for syntax faces (keywords, functions, variables)."
+  :type 'boolean
+  :group 'dracula)
+
 (defvar dracula-use-24-bit-colors-on-256-colors-terms nil
   "Use true colors even on terminals announcing less capabilities.
 
@@ -245,8 +250,12 @@ read it before opening a new issue about your will.")
                (font-lock-comment-delimiter-face :inherit shadow)
                (font-lock-constant-face :foreground ,dracula-purple)
                (font-lock-doc-face :foreground ,dracula-comment)
-               (font-lock-function-name-face :foreground ,dracula-green :weight bold)
-               (font-lock-keyword-face :foreground ,dracula-pink :weight bold)
+               (font-lock-function-name-face :foreground ,dracula-green
+                                             ,@(when dracula-bolder-keywords
+                                                 (list :weight 'bold)))
+               (font-lock-keyword-face :foreground ,dracula-pink
+                                       ,@(when dracula-bolder-keywords
+                                           (list :weight 'bold)))
                (font-lock-negation-char-face :foreground ,dracula-cyan)
                (font-lock-number-face :foreground ,dracula-purple)
                (font-lock-operator-face :foreground ,dracula-pink)
@@ -256,7 +265,9 @@ read it before opening a new issue about your will.")
                (font-lock-regexp-grouping-construct :foreground ,dracula-purple)
                (font-lock-string-face :foreground ,dracula-yellow)
                (font-lock-type-face :inherit font-lock-builtin-face)
-               (font-lock-variable-name-face :foreground ,dracula-fg :weight bold)
+               (font-lock-variable-name-face :foreground ,dracula-fg
+                                             ,@(when dracula-bolder-keywords
+                                                 (list :weight 'bold)))
                (font-lock-warning-face :inherit warning :background ,bg2)
                ;; auto-complete
                (ac-completion-face :underline t :foreground ,dracula-pink)
